@@ -1,5 +1,12 @@
 import json
 
+import wagtail
+from django.core.exceptions import PermissionDenied
+from django.utils.translation import gettext as _
+
+if wagtail.VERSION >= (2, 16):
+    from wagtail.core.actions.move_page import MovePageAction
+
 from wagtail.core.models import Page, Site
 
 from .models import TrashCanPage
@@ -11,7 +18,7 @@ def trash_can_for_request(request):
 
     if not trash_can.exists():
         trash_can = TrashCanPage(
-            title="Trash Can",
+            title=_("Trash Can"),
             has_unpublished_changes=True,
             live=False,
         )
@@ -42,7 +49,13 @@ def restore_and_move_page(rb, move_to_page, request):
     if not rb.page.permissions_for_user(request.user).can_move():
         raise PermissionDenied
 
-    rb.page.move(move_to_page, pos="first-child", user=request.user)
+    if wagtail.VERSION >= (2, 16):
+        action = MovePageAction(
+            rb.page, move_to_page, pos="first-child", user=request.user
+        )
+        action.execute(skip_permission_checks=True)
+    else:
+        rb.page.move(move_to_page, pos="first-child", user=request.user)
 
     to_be_published_ids = json.loads(rb.data)["published"]
 
